diff --git a/src/caoscrawler/identifiable_adapters.py b/src/caoscrawler/identifiable_adapters.py
index b1accd25a35b361472649095b20da488b3d8e2d8..9fa297ccc8dd7cb32071b01188d167c28f6a94fd 100644
--- a/src/caoscrawler/identifiable_adapters.py
+++ b/src/caoscrawler/identifiable_adapters.py
@@ -149,13 +149,17 @@ identifiabel, identifiable and identified record) for a Record.
         return query_string
 
     def check_identifying_props(self, node, raise_exception=True):
-        """checks whether all identifying properties exist and raises an error if not
+        """checks whether all identifying properties exist and raises an error if
+        that's not the case. It furthermore raises an error if "name" is part of
+        the identifiable, but the node does not have a name.
 
         If raise_exception is False, the function returns False instead of raising an error.
 
         Backreferences are not checked.
 
         Returns True if all identifying properties exist.
+
+        Last review by Alexander Schlemmer on 2024-05-24.
         """
         if node.registered_identifiable is None:
             if raise_exception: